{theme=documentation}

\include{"../include.md"}

\title{Blockquotes "If something was already said."}



## Plain Markdown

```
> Blockquotes are very handy in email to emulate reply text.
> This line is part of the same quote.

Quote break.

> This is a very long line that will still be quoted properly when it wraps. Oh boy let's keep writing to make sure this is long enough to actually wrap for everyone. Oh, you can *put* **Markdown** into a blockquote. 
```
\Output[
> Blockquotes are very handy in email to emulate reply text.
> This line is part of the same quote.

Quote break.

> This is a very long line that will still be quoted properly when it wraps. Oh boy let's keep writing to make sure this is long enough to actually wrap for everyone. Oh, you can *put* **Markdown** into a blockquote. 
]

## Additional Options
Sometimes it is nicer to include the source of the quote right in the element.
```
{source="Steve Martin"}
> A day without sunshine is like, you know, night.
```
\Output[
{source="Steve Martin"}
> A day without sunshine is like, you know, night.
]
